@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostDataChecker.cpp 2281 2006-12-18 14:26:48Z svn $
+ * $Id: PostDataChecker.cpp 2392 2007-03-23 16:29:24Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,7 +36,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2281 2006-12-18 14:26:48Z svn $");
+SOURCE_INFO_ADD("$Id: PostDataChecker.cpp 2392 2007-03-23 16:29:24Z svn $");
 
 const char PostDataChecker::HTML_EXT[]      = "htm";
 
@@ -54,6 +54,7 @@ void PostDataChecker::validate_uitem(apr_pool_t *pool, apr_uint64_t file_size,
     const char *file_ext;
 
     validate_file_name(pool, file_name);
+    validate_file_mime(pool, *file_mime);
     validate_comment(pool, comment);
     file_ext = get_file_ext(*file_name);
     validate_file_ext(file_ext);
@@ -122,6 +123,19 @@ void PostDataChecker::validate_file_name(apr_pool_t *pool,
     }
 }
 
+void PostDataChecker::validate_file_mime(apr_pool_t *pool,
+                                         const char *file_mime)
+{
+    for (const char *mime = file_mime; *mime != '\0'; mime++) {
+        if (isalnum(*mime) || (*mime == '-') || (*mime == '+') ||
+            (*mime == '.') || (*mime == '/')) {
+            continue;
+        }
+
+        THROW(MESSAGE_POST_FILE_MIME_INVALID);
+    }
+}
+
 void PostDataChecker::validate_comment(apr_pool_t *pool, const char **comment)
 {
     apr_size_t escaped_length;
