@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.cpp 2327 2006-12-29 18:07:16Z svn $
+ * $Id: TemplateParser.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -36,7 +36,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: TemplateParser.cpp 2327 2006-12-29 18:07:16Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateParser.cpp 2388 2007-03-10 11:34:50Z svn $");
 
 #define AS_NODE(pointer)            reinterpret_cast<node_t *>(pointer)
 #define AS_UNCONST_NODE(pointer)    const_cast<node_t *>(pointer)
@@ -1204,7 +1204,7 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
         dump_level = 0;
     }
 
-    if (!is_exist(pool, tmpl_file_path)) {
+    if (!File::is_exist(pool, tmpl_file_path)) {
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
     }
 
