@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemVariableCreator.cpp 2297 2006-12-24 03:13:15Z svn $
+ * $Id: UploadItemVariableCreator.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2297 2006-12-24 03:13:15Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2388 2007-03-10 11:34:50Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -254,10 +254,10 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
     data_dir_path = argv[1];
     tmpl_file_path = argv[2];
 
-    if (!is_exist(pool, data_dir_path)) {
+    if (!File::is_exist(pool, data_dir_path)) {
         THROW(MESSAGE_DATA_DIR_NOT_FOUND);
     }
-    if (!is_exist(pool, tmpl_file_path)) {
+    if (!File::is_exist(pool, tmpl_file_path)) {
         THROW(MESSAGE_TMPL_FILE_NOT_FOUND);
     }
 
