@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2285 2006-12-22 00:53:58Z svn $
+ * $Id: UploaderConfig.cpp 2388 2007-03-10 11:34:50Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -46,7 +46,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2285 2006-12-22 00:53:58Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2388 2007-03-10 11:34:50Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -250,17 +250,32 @@ const char *UploaderConfig::to_string(apr_pool_t *pool)
  *****************************************************************************/
 void UploaderConfig::check()
 {
-    if ((base_url == NULL) ||
-        (data_dir_path == NULL) ||
-        (file_dir_path == NULL) ||
-        (thumb_dir_path == NULL) ||
-        (temp_dir_path == NULL)) {
+    if (base_url == NULL) {
         THROW(MESSAGE_CONF_PARAM_COMPULSORY_NOT_SPECIFIED);
     }
 
+    check_dir(data_dir_path);
+    check_dir(file_dir_path);
+    check_dir(thumb_dir_path);
+    check_dir(temp_dir_path);
+
     check_template();
 }
 
+void UploaderConfig::check_dir(const char *dir_path)
+{
+    if (dir_path == NULL) {
+        THROW(MESSAGE_CONF_PARAM_COMPULSORY_NOT_SPECIFIED);
+    }
+    if (!File::is_writable(pool_, dir_path)) {
+        throw apr_pstrcat(pool_,
+                          MESSAGE_DIR_NOT_WRITABLE,
+                          " [", dir_path, "]",
+                          " (" __FILE__ ":" APR_STRINGIFY(__LINE__) ")",
+                          NULL);
+    }
+}
+
 void UploaderConfig::check_template()
 {
     for (apr_size_t i = 0; i < ARRAY_SIZE_OF(tmpls_); i++) {
