@@ -22,23 +22,25 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_util.cpp 2170 2006-12-04 17:23:49Z svn $
+ * $Id: uploader_util.cpp 2220 2006-12-10 06:10:27Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
 #include "apr_strings.h"
+#include "apr_network_io.h"
 
 #include "uploader_util.h"
 
 #include "UploaderConfig.h"
 #include "UploadItemIO.h"
 #include "PostFlowController.h"
+#include "DownloadFlowController.h"
 #include "CharCodeConverter.h"
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: uploader_util.cpp 2170 2006-12-04 17:23:49Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_util.cpp 2220 2006-12-10 06:10:27Z svn $");
 
 const char *get_word(apr_pool_t *pool, const char **input,
                      const char delimiter)
@@ -107,22 +109,32 @@ const char *get_dispos_encoding(const char *user_agent)
     return encoding;
 }
 
-bool can_post(UploaderConfig *config, const char *ip_address)
+bool can_post(UploaderConfig *config, apr_sockaddr_t *ip_address)
 {
     if (config->is_debug_mode) {
         return true;
     }
 
-    return config->get_flow_controller()->can_post(ip_address);
+    return config->get_post_flow_controller()->can_post(ip_address);
 }
 
-void regist_post(UploaderConfig *config, const char *ip_address)
+void regist_post(UploaderConfig *config, apr_sockaddr_t *ip_address)
 {
     if (config->is_debug_mode) {
         return;
     }
 
-    config->get_flow_controller()->regist_post(ip_address);
+    config->get_post_flow_controller()->regist_post(ip_address);
+}
+
+bool can_download(UploaderConfig *config, apr_sockaddr_t *ip_address)
+{
+    return config->get_download_flow_controller()->add_session(ip_address);
+}
+
+void finish_download(UploaderConfig *config, apr_sockaddr_t *ip_address)
+{
+    config->get_download_flow_controller()->remove_session(ip_address);
 }
 
 // Local Variables:
