@@ -22,13 +22,19 @@ run() {
 
 run ./configure --enable-thumbnail
 run ./util/win_build.pl
+
 run make -f GNUmakefile.dist dist-sf
 run make -f GNUmakefile.dist dist-win-sf
 
+run cp mod_uploader-ap2.0.so /home/apache/${PACKAGE}/
+run cp mod_uploader-ap2.2.so /home/apache/${PACKAGE}/
+
 (
     run cd doc
     run make doc-update
+    run make doc-api
     run cp apache.htm apache-win.htm /home/apache/${PACKAGE}/
+    run cp -r api /home/apache/${PACKAGE}/
 )
 
 (
