@@ -16,7 +16,7 @@ my $sf;
 
 GetOptions(\%args, "package=s", "mode=s", "version=s", "file=s");
 
-$pass = $ENV{'PASS'} || read_password('sourceforge pass: ', 0, 1);
+$pass = $ENV{'SF_PASS'} || read_password('sourceforge pass: ', 0, 1);
 
 $sf = WWW::SourceforgeJP->new(PROJECT);
 $sf->login(USER, $pass);
